<?php declare(strict_types=1);

namespace Pinpoint\DropShipping\Model\Product\Attribute\Source;
use Pinpoint\DropShipping\Model\ResourceModel\Supplier\CollectionFactory;


class DefaultSupplier extends \Magento\Eav\Model\Entity\Attribute\Source\AbstractSource
{
    /**
     * @var \Magento\Eav\Model\ResourceModel\Entity\Attribute
     */
    private $_eavEntityAttribute;

    /**
     * @var CollectionFactory
     */
    private $_collectionFactory;

    /**
     * DefaultSupplier constructor.
     * @param \Magento\Eav\Model\ResourceModel\Entity\Attribute $_eavEntityAttribute
     * @param CollectionFactory $_collectionFactory
     */
    public function __construct(\Magento\Eav\Model\ResourceModel\Entity\Attribute $_eavEntityAttribute, CollectionFactory $_collectionFactory)
    {
        $this->_eavEntityAttribute = $_eavEntityAttribute;
        $this->_collectionFactory = $_collectionFactory;
    }

    /**
     * getAllOptions
     *
     * @return array
     */
    public function getAllOptions()
    {
        $emptyOption = [['label' => ' ', 'value' => '']];
        $this->_options = array_merge($emptyOption, $this->_collectionFactory->create()->toOptionArray());
        return $this->_options;
    }

    /**
     * @return array
     */
    public function getFlatColumns()
    {
        $attributeCode = $this->getAttribute()->getAttributeCode();
        return [
            $attributeCode => [
                'unsigned' => false,
                'default' => null,
                'extra' => null,
                'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                'length' => 255,
                'nullable' => true,
                'comment' => $attributeCode . ' column',
            ],
        ];
    }

    /**
     * @return array
     */
    public function getFlatIndexes()
    {
        $indexes = [];

        $index = 'IDX_' . strtoupper($this->getAttribute()->getAttributeCode());
        $indexes[$index] = ['type' => 'index', 'fields' => [$this->getAttribute()->getAttributeCode()]];

        return $indexes;
    }

    /**
     * @param int $store
     * @return \Magento\Framework\DB\Select|null
     */
    public function getFlatUpdateSelect($store)
    {
        return $this->_eavEntityAttribute->create()->getFlatUpdateSelect($this->getAttribute(), $store);
    }
}

